/*
	*
	* Copyright 2019-2021 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project (https://gitlab.com/desq/)
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* at your option, any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

// Local Headers
#include <desqui/DesQUI.hpp>

class DesQActionBar;

class DesQMainWindow : public QMainWindow {
	Q_OBJECT

	public:
		DesQMainWindow();

		/* Main Window */
		void setMainView( QWidget * );

		/* Application Title */
		void setAppTitle( QString );

		/* Application icon */
		void setAppIcon( QString );
		void setAppIcon( QIcon );

		/* Add items to the titlebar */
		void addTitleBarWidget( QWidget *, int );

		/* Add a floating action to the main view */
		void setFloatingAction( QString name, QIcon icon, QString target );
		void setFloatingWidget( QWidget *widget );

		/* Add items to actionBar */
		int addAction( int page, QString name, QIcon icon, QString target, QString tooltip, bool checkable, bool checked );
		void addSpace( int page, bool stretch );
		void addSeparator( int page );

		/* Change icon */
		void setIcon( int page, int item, QIcon icon );

		/* Enable/disable actions */
		void setActionEnabled( int page, int item );
		void setActionDisabled( int page, int item );

		/* Event filter for special action filtering */
		bool eventFilter( QObject *obj, QEvent *event ) override;

	private:
		void createUI();

		QWidget *mainView;
		QWidget *titleBar;
		DesQActionBar *actionBar;

		QWidget *mFloatingWidget = nullptr;

		QGridLayout *mainLyt;

		QToolButton *iconBtn;
		QToolButton *quitBtn;

		QLabel *iconLbl;
		QLabel *titleLbl;

		QSizeGrip *resizeGrip;

		bool mobileUI;

		/* Show/hide the side actionBar */
		void toggleActionBar();

		/* Check if our UI is in compact mode. Otherwise maximize/restore window */
		void tryMaximize();

	Q_SIGNALS:
		void action( QString );
};
